
# Enum: presence_enum


enumeration of conditions by which a slot value should be set

URI: [linkml:presence_enum](https://w3id.org/linkml/presence_enum)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| UNCOMMITTED |  |  |  |
| PRESENT |  |  |  |
| ABSENT |  |  |  |

